@@ -1,3 +1,6 @@
+from collections import deque
+from functools import wraps
+from inspect import Parameter, signature
 from itertools import chain
 import re
 
@@ -19,7 +22,7 @@ def dictify(*items):
             if part in current_dict:
                 if not isinstance(current_dict[part], dict):
                     raise TypeError(
-                        "{} is set to item: {}".format(current_path, current_dict[part])
+                        f"{current_path} is set to item: {current_dict[part]}"
                     )
             else:
                 current_dict[part] = {}
@@ -29,9 +32,7 @@ def dictify(*items):
         part = parts[-1]
         current_path.append(part)
         if part in current_dict:
-            raise TypeError(
-                "{} already exists: {}".format(current_path, current_dict[part])
-            )
+            raise TypeError(f"{current_path} already exists: {current_dict[part]}")
         current_dict[part] = item
 
     return final_dict
@@ -72,3 +73,46 @@ def extract_namespace_name(name):
     if match:
         return match.groups()
     return ("", name)
+
+
+def last_item_or_none(iterable):
+    try:
+        return deque(iterable, maxlen=1)[0]
+    except IndexError:
+        return None
+
+
+def consume(iterable):
+    iterator = iter(iterable)
+    try:
+        next(iterator)
+    except StopIteration:
+        return False
+    last_item_or_none(iterator)
+    return True
+
+
+def transform_none_return_value(fct):
+    @wraps(fct)
+    def wrapped(*args, **kwargs):
+        return_value = fct(*args, **kwargs)
+        if return_value is None:
+            return ()  # empty iterable
+        return return_value
+
+    return wrapped
+
+
+def get_mandatory_params(fct):
+    sig = signature(fct)
+    return tuple(
+        param.name
+        for param in sig.parameters.values()
+        if param.kind
+        in (
+            Parameter.POSITIONAL_ONLY,
+            Parameter.POSITIONAL_OR_KEYWORD,
+            Parameter.KEYWORD_ONLY,
+        )
+        and param.default == sig.empty
+    )
