@@ -1,17 +1,15 @@
 from pathlib import Path
 
-from bigxml import Parser, XMLHandler, xml_handle_element
+from bigxml import Parser, xml_handle_element
 
 
-def test_maths_eval():
-    class Handler(XMLHandler):
-        @staticmethod
-        @xml_handle_element("comments", "comment")
-        def handle_author(node):
-            yield node.text
+def test_comments():
+    @xml_handle_element("comments", "comment")
+    def handler(node):
+        yield node.text
 
     with (Path(__file__).parent / "comments.xml").open("rb") as stream:
-        items = Parser(stream).iter_from(Handler())
+        items = Parser(stream).iter_from(handler)
         assert next(items) == "Test"
         assert next(items) == "Hello everyone!"
         assert next(items) == (
