@@ -2,11 +2,12 @@ from datetime import datetime
 from lzma import LZMAFile
 from pathlib import Path
 
-from bigxml import Parser, XMLHandler, xml_handle_element, xml_handle_text
+from bigxml import Parser, xml_handle_element, xml_handle_text
 
 
 def test_wikipedia_export():
-    class Revision(XMLHandler):
+    @xml_handle_element("mediawiki", "page", "revision")
+    class Revision:
         def __init__(self):
             self.author = None
             self.date = None
@@ -17,19 +18,18 @@ def test_wikipedia_export():
 
         @xml_handle_text("timestamp")
         def handle_date(self, node):
-            self.date = datetime.strptime(node.text, r"%Y-%m-%dT%H:%M:%SZ")
+            self.date = datetime.strptime(node.text, "%Y-%m-%dT%H:%M:%SZ")
 
-    class Handler(XMLHandler):
-        @staticmethod
-        @xml_handle_element("mediawiki", "page", "revision")
-        def handle_revision(node):
-            yield node.return_from(Revision())
+        def xml_handler(self):
+            # at this point the <revision> tag is fully parsed
+            # yield the Revision instance
+            yield self
 
     with LZMAFile(Path(__file__).parent / "wikipedia_python_export.xml.xz") as stream:
-        items = list(Parser(stream).iter_from(Handler()))
+        items = list(Parser(stream).iter_from(Revision))
         assert len(items) == 1000
+        assert all(isinstance(item, Revision) for item in items)
         revision = items[-1]
-        assert isinstance(revision, Revision)
         assert revision.author == "Lulu of the Lotus-Eaters"
         assert revision.date.year == 2006
         assert revision.date.month == 4
